@@ -33,8 +33,13 @@ sw_debug_init (const char *string)
     { "online", SW_DEBUG_ONLINE },
     { "item", SW_DEBUG_ITEM },
     { "twitter", SW_DEBUG_TWITTER },
-    { "myspace", SW_DEBUG_MYSPACE },
-    { "lastfm", SW_DEBUG_LASTFM }
+    { "lastfm", SW_DEBUG_LASTFM },
+    { "core", SW_DEBUG_CORE },
+    { "vimeo", SW_DEBUG_VIMEO },
+    { "flickr", SW_DEBUG_FLICKR },
+    { "smugmug", SW_DEBUG_SMUGMUG },
+    { "photobucket", SW_DEBUG_PHOTOBUCKET },
+    { "client-monitor", SW_DEBUG_CLIENT_MONITOR }
   };
 
   if (G_LIKELY (setup_done))
